---
feature_story: FS_47_63_35_61
feature_title: env vars
feature_status: TEST
---

These are environment variables used by `argrelay`:

*   `ARGRELAY_DEBUG` used to enable debug output - see `ShellContext.is_debug_enabled`.

    To produce debug output:
    *   Some logic simply needs to detect whether `ARGRELAY_DEBUG` is defined or not.
    *   For shell scripts, `ARGRELAY_DEBUG` value must contains char `s` ("script").
    *   For client-server perf output, `ARGRELAY_DEBUG` value must contains char `p` ("performance").

*   `ARGRELAY_DEV_SHELL` used while running `@/exe/dev_shell.bash`, for example, to run some tests conditionally.

*   `ARGRELAY_BOOTSTRAP_DEV_ENV` used while running `@/exe/bootstrap_dev_env.bash`, for example, to run some tests conditionally.

*   `ARGRELAY_CONF_BASE_DIR` specifies base dir for all config files (default ~ = user home).

    See also `FS_16_07_78_84.conf_dir_priority.md`.

*   `ARGRELAY_CLIENT_COMMAND` provides the first (any) command name configured in `@/conf/argrelay_rc_conf.bash`.

    This is mostly used in testing to programmatically invoke non-hard-coded command.

*   `ARGRELAY_USER_SHELL_OPTS` is set by user script.

    The value contains shell options to restore before passing control to nested interactive shell.
